==> haskell-hsyaml-aeson-0.2.0.0-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsYAML-aeson
version:              0.2.0.0
visibility:           public
id:                   HsYAML-aeson-0.2.0.0-G57QrsxJKI07uI9S1Ik5Aa
key:                  HsYAML-aeson-0.2.0.0-G57QrsxJKI07uI9S1Ik5Aa
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  92d48c3a93a87d184718211549045807
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-8.10.3/site-local/HsYAML-aeson-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/HsYAML-aeson-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/HsYAML-aeson-0.2.0.0
hs-libraries:         HSHsYAML-aeson-0.2.0.0-G57QrsxJKI07uI9S1Ik5Aa
depends:
    HsYAML-0.2.1.0-5Mt9c9YE0Jx1G0wzoeNb47
    aeson-1.5.5.1-AwM5PjoCXg9Gz7zfwWBIzV base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1 mtl-2.2.2
    scientific-0.3.6.2-IZlBItsUzb8GTx71NeTgGr text-1.2.4.1
    unordered-containers-0.2.13.0-JMmUMTViutlBDpWEaCrbh4
    vector-0.12.2.0-CTKdHZ2Betb5QHFFflD8i8

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyaml-aeson-0.2.0.0-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsYAML-aeson
version:              0.2.0.0
visibility:           public
id:                   HsYAML-aeson-0.2.0.0-Jiup3ctPBxi707AqQ51VGE
key:                  HsYAML-aeson-0.2.0.0-Jiup3ctPBxi707AqQ51VGE
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  d17937567147730ac32870f8e113f194
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-8.10.4/site-local/HsYAML-aeson-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/HsYAML-aeson-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/HsYAML-aeson-0.2.0.0
hs-libraries:         HSHsYAML-aeson-0.2.0.0-Jiup3ctPBxi707AqQ51VGE
depends:
    HsYAML-0.2.1.0-rn9qzb7VbT3WGRft2atgH
    aeson-1.5.5.1-6NWVvXrflAc8ojSfaztJWW base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1 mtl-2.2.2
    scientific-0.3.6.2-9ZxFCFgnJAMDhSD87n407w text-1.2.4.1
    unordered-containers-0.2.13.0-48OepUjtvPcKuQlUwC19ed
    vector-0.12.2.0-Ah3gN1EocbtK6SkxatFMVl

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
